# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowsRunRequestInputsValue = typing.Union[
    bool, typing.Dict[str, typing.Optional[typing.Any]], float, int, typing.List[typing.Optional[typing.Any]], str
]
